@@ -15,6 +15,7 @@ class MysqlCommando(object):
         (r'-?\d+', int),
         (r'-?\d*\.?\d*([Ee][+-]?\d+)?', float),
         (r'\d{4}-\d\d-\d\d \d\d:\d\d:\d\d', lambda d: datetime.datetime.strptime(d, MysqlCommando.ISO_FORMAT)),
+        (r'NULL', lambda d: None),
     )
     QUERY_LAST_INSERT_ID = """
     ;SELECT last_insert_id() as last_insert_id;
@@ -56,7 +57,7 @@ class MysqlCommando(object):
                        '-u%s' % self.username,
                        '-p%s' % self.password,
                        '-h%s' % self.hostname,
-                       '--default-character-set', self.encoding,
+                       '--default-character-set=%s' % self.encoding,
                        '-B', '-e', query, self.database]
         else:
             command = ['mysql',
@@ -80,7 +81,7 @@ class MysqlCommando(object):
                        '-u%s' % self.username,
                        '-p%s' % self.password,
                        '-h%s' % self.hostname,
-                       '--default-character-set', self.encoding,
+                       '--default-character-set=%s' % self.encoding,
                        '-B', self.database]
         else:
             command = ['mysql',
@@ -96,10 +97,6 @@ class MysqlCommando(object):
             return self._output_to_result(output, cast=cast)
 
     def _output_to_result(self, output, cast):
-        if self.encoding:
-            output = unicode(output, encoding=self.encoding, errors='replace')
-        else:
-            output = unicode(output, errors='replace')
         result = []
         lines = output.strip().split('\n')
         fields = lines[0].split('\t')
